@@ -1,21 +1,18 @@
+from __future__ import annotations
+
+import warnings
+from collections.abc import AsyncGenerator, Generator, Iterator
 from typing import (
     TYPE_CHECKING,
     Any,
-    AsyncGenerator,
-    Generator,
     Generic,
-    Iterator,
-    List,
+    Literal,
     Optional,
-    Tuple,
-    Type,
     TypeVar,
-    Union,
     overload,
 )
 
-from pypika import Table
-from typing_extensions import Literal
+from pypika_tortoise import Table
 
 from tortoise.exceptions import ConfigurationError, NoValuesFetched, OperationalError
 from tortoise.fields.base import CASCADE, SET_NULL, Field, OnDelete
@@ -48,9 +45,9 @@ class ReverseRelation(Generic[MODEL]):
 
     def __init__(
         self,
-        remote_model: Type[MODEL],
+        remote_model: type[MODEL],
         relation_field: str,
-        instance: "Model",
+        instance: Model,
         from_field: str,
     ) -> None:
         self.remote_model = remote_model
@@ -59,10 +56,10 @@ class ReverseRelation(Generic[MODEL]):
         self.from_field = from_field
         self._fetched = False
         self._custom_query = False
-        self.related_objects: List[MODEL] = []
+        self.related_objects: list[MODEL] = []
 
     @property
-    def _query(self) -> "QuerySet[MODEL]":
+    def _query(self) -> QuerySet[MODEL]:
         if not self.instance._saved_in_db:
             raise OperationalError(
                 "This objects hasn't been instanced, call .save() before calling related queries"
@@ -75,7 +72,7 @@ class ReverseRelation(Generic[MODEL]):
         self._raise_if_not_fetched()
         return item in self.related_objects
 
-    def __iter__(self) -> "Iterator[MODEL]":
+    def __iter__(self) -> Iterator[MODEL]:
         self._raise_if_not_fetched()
         return self.related_objects.__iter__()
 
@@ -91,46 +88,46 @@ class ReverseRelation(Generic[MODEL]):
         self._raise_if_not_fetched()
         return self.related_objects[item]
 
-    def __await__(self) -> Generator[Any, None, List[MODEL]]:
+    def __await__(self) -> Generator[Any, None, list[MODEL]]:
         return self._query.__await__()
 
-    async def __aiter__(self) -> AsyncGenerator[Any, MODEL]:
+    async def __aiter__(self) -> AsyncGenerator[MODEL, None]:
         if not self._fetched:
             self._set_result_for_query(await self)
         for val in self.related_objects:
             yield val
 
-    def filter(self, *args: "Q", **kwargs: Any) -> "QuerySet[MODEL]":
+    def filter(self, *args: Q, **kwargs: Any) -> QuerySet[MODEL]:
         """
         Returns a QuerySet with related elements filtered by args/kwargs.
         """
         return self._query.filter(*args, **kwargs)
 
-    def all(self) -> "QuerySet[MODEL]":
+    def all(self) -> QuerySet[MODEL]:
         """
         Returns a QuerySet with all related elements.
         """
         return self._query
 
-    def order_by(self, *orderings: str) -> "QuerySet[MODEL]":
+    def order_by(self, *orderings: str) -> QuerySet[MODEL]:
         """
         Returns a QuerySet related elements in order.
         """
         return self._query.order_by(*orderings)
 
-    def limit(self, limit: int) -> "QuerySet[MODEL]":
+    def limit(self, limit: int) -> QuerySet[MODEL]:
         """
         Returns a QuerySet with at most «limit» related elements.
         """
         return self._query.limit(limit)
 
-    def offset(self, offset: int) -> "QuerySet[MODEL]":
+    def offset(self, offset: int) -> QuerySet[MODEL]:
         """
         Returns a QuerySet with all related elements offset by «offset».
         """
         return self._query.offset(offset)
 
-    def _set_result_for_query(self, sequence: List[MODEL], attr: Optional[str] = None) -> None:
+    def _set_result_for_query(self, sequence: list[MODEL], attr: str | None = None) -> None:
         self._fetched = True
         self.related_objects = sequence
         if attr:
@@ -148,12 +145,12 @@ class ManyToManyRelation(ReverseRelation[MODEL]):
     Many-to-many relation container for :func:`.ManyToManyField`.
     """
 
-    def __init__(self, instance: "Model", m2m_field: "ManyToManyFieldInstance[MODEL]") -> None:
+    def __init__(self, instance: Model, m2m_field: ManyToManyFieldInstance[MODEL]) -> None:
         super().__init__(m2m_field.related_model, m2m_field.related_name, instance, "pk")
         self.field = m2m_field
         self.instance = instance
 
-    async def add(self, *instances: MODEL, using_db: "Optional[BaseDBAsyncClient]" = None) -> None:
+    async def add(self, *instances: MODEL, using_db: BaseDBAsyncClient | None = None) -> None:
         """
         Adds one or more of ``instances`` to the relation.
 
@@ -198,15 +195,13 @@ class ManyToManyRelation(ReverseRelation[MODEL]):
                 query = query.insert(pk_f, pk_b)
             await db.execute_query(*query.get_parameterized_sql())
 
-    async def clear(self, using_db: "Optional[BaseDBAsyncClient]" = None) -> None:
+    async def clear(self, using_db: BaseDBAsyncClient | None = None) -> None:
         """
         Clears ALL relations.
         """
         await self._remove_or_clear(using_db=using_db)
 
-    async def remove(
-        self, *instances: MODEL, using_db: "Optional[BaseDBAsyncClient]" = None
-    ) -> None:
+    async def remove(self, *instances: MODEL, using_db: BaseDBAsyncClient | None = None) -> None:
         """
         Removes one or more of ``instances`` from the relation.
 
@@ -218,8 +213,8 @@ class ManyToManyRelation(ReverseRelation[MODEL]):
 
     async def _remove_or_clear(
         self,
-        instances: Optional[Tuple[MODEL, ...]] = None,
-        using_db: "Optional[BaseDBAsyncClient]" = None,
+        instances: tuple[MODEL, ...] | None = None,
+        using_db: BaseDBAsyncClient | None = None,
     ) -> None:
         db = using_db or self.remote_model._meta.db
         through_table = Table(self.field.through)
@@ -247,13 +242,13 @@ class RelationalField(Field[MODEL]):
 
     def __init__(
         self,
-        related_model: "Type[MODEL]",
-        to_field: Optional[str] = None,
+        related_model: type[MODEL],
+        to_field: str | None = None,
         db_constraint: bool = True,
         **kwargs: Any,
     ) -> None:
         super().__init__(**kwargs)
-        self.related_model: "Type[MODEL]" = related_model
+        self.related_model: type[MODEL] = related_model
         self.to_field: str = to_field  # type: ignore
         self.to_field_instance: Field = None  # type: ignore
         self.db_constraint = db_constraint
@@ -261,16 +256,16 @@ class RelationalField(Field[MODEL]):
     if TYPE_CHECKING:
 
         @overload
-        def __get__(self, instance: None, owner: Type["Model"]) -> "RelationalField[MODEL]": ...
+        def __get__(self, instance: None, owner: type[Model]) -> RelationalField[MODEL]: ...
 
         @overload
-        def __get__(self, instance: "Model", owner: Type["Model"]) -> MODEL: ...
+        def __get__(self, instance: Model, owner: type[Model]) -> MODEL: ...
 
         def __get__(
-            self, instance: Optional["Model"], owner: Type["Model"]
-        ) -> "RelationalField[MODEL] | MODEL": ...
+            self, instance: Model | None, owner: type[Model]
+        ) -> RelationalField[MODEL] | MODEL: ...
 
-        def __set__(self, instance: "Model", value: MODEL) -> None: ...
+        def __set__(self, instance: Model, value: MODEL) -> None: ...
 
     def describe(self, serializable: bool) -> dict:
         desc = super().describe(serializable)
@@ -289,7 +284,7 @@ class ForeignKeyFieldInstance(RelationalField[MODEL]):
     def __init__(
         self,
         model_name: str,
-        related_name: Union[Optional[str], Literal[False]] = None,
+        related_name: str | None | Literal[False] = None,
         on_delete: OnDelete = CASCADE,
         **kwargs: Any,
     ) -> None:
@@ -315,24 +310,24 @@ class ForeignKeyFieldInstance(RelationalField[MODEL]):
 class BackwardFKRelation(RelationalField[MODEL]):
     def __init__(
         self,
-        field_type: "Type[MODEL]",
+        field_type: type[MODEL],
         relation_field: str,
         relation_source_field: str,
         null: bool,
-        description: Optional[str],
+        description: str | None,
         **kwargs: Any,
     ) -> None:
         super().__init__(field_type, null=null, **kwargs)
         self.relation_field: str = relation_field
         self.relation_source_field: str = relation_source_field
-        self.description: Optional[str] = description
+        self.description: str | None = description
 
 
 class OneToOneFieldInstance(ForeignKeyFieldInstance[MODEL]):
     def __init__(
         self,
         model_name: str,
-        related_name: Union[Optional[str], Literal[False]] = None,
+        related_name: str | None | Literal[False] = None,
         on_delete: OnDelete = CASCADE,
         **kwargs: Any,
     ) -> None:
@@ -350,18 +345,25 @@ class ManyToManyFieldInstance(RelationalField[MODEL]):
     def __init__(
         self,
         model_name: str,
-        through: Optional[str] = None,
-        forward_key: Optional[str] = None,
+        through: str | None = None,
+        forward_key: str | None = None,
         backward_key: str = "",
         related_name: str = "",
         on_delete: OnDelete = CASCADE,
-        field_type: "Type[MODEL]" = None,  # type: ignore
-        create_unique_index: bool = True,
+        field_type: type[MODEL] = None,  # type: ignore
+        unique: bool = True,
         **kwargs: Any,
     ) -> None:
         # TODO: rename through to through_table
         # TODO: add through to use a Model
-        super().__init__(field_type, **kwargs)
+        if "create_unique_index" in kwargs:
+            warnings.warn(
+                "Parameter `create_unique_index` is deprecated! Use `unique` instead.",
+                DeprecationWarning,
+                stacklevel=2,
+            )
+            unique = kwargs.pop("create_unique_index")
+        super().__init__(field_type, unique=unique, **kwargs)
         self.validate_model_name(model_name)
         self.model_name: str = model_name
         self.related_name: str = related_name
@@ -370,7 +372,6 @@ class ManyToManyFieldInstance(RelationalField[MODEL]):
         self.through: str = through  # type: ignore
         self._generated: bool = False
         self.on_delete = on_delete
-        self.create_unique_index = create_unique_index
 
     def describe(self, serializable: bool) -> dict:
         desc = super().describe(serializable)
@@ -387,34 +388,34 @@ class ManyToManyFieldInstance(RelationalField[MODEL]):
 @overload
 def OneToOneField(
     model_name: str,
-    related_name: Union[Optional[str], Literal[False]] = None,
+    related_name: str | None | Literal[False] = None,
     on_delete: OnDelete = CASCADE,
     db_constraint: bool = True,
     *,
     null: Literal[True],
     **kwargs: Any,
-) -> "OneToOneNullableRelation[MODEL]": ...
+) -> OneToOneNullableRelation[MODEL]: ...
 
 
 @overload
 def OneToOneField(
     model_name: str,
-    related_name: Union[Optional[str], Literal[False]] = None,
+    related_name: str | None | Literal[False] = None,
     on_delete: OnDelete = CASCADE,
     db_constraint: bool = True,
     null: Literal[False] = False,
     **kwargs: Any,
-) -> "OneToOneRelation[MODEL]": ...
+) -> OneToOneRelation[MODEL]: ...
 
 
 def OneToOneField(
     model_name: str,
-    related_name: Union[Optional[str], Literal[False]] = None,
+    related_name: str | None | Literal[False] = None,
     on_delete: OnDelete = CASCADE,
     db_constraint: bool = True,
     null: bool = False,
     **kwargs: Any,
-) -> "OneToOneRelation[MODEL] | OneToOneNullableRelation[MODEL]":
+) -> OneToOneRelation[MODEL] | OneToOneNullableRelation[MODEL]:
     """
     OneToOne relation field.
 
@@ -462,34 +463,34 @@ def OneToOneField(
 @overload
 def ForeignKeyField(
     model_name: str,
-    related_name: Union[Optional[str], Literal[False]] = None,
+    related_name: str | None | Literal[False] = None,
     on_delete: OnDelete = CASCADE,
     db_constraint: bool = True,
     *,
     null: Literal[True],
     **kwargs: Any,
-) -> "ForeignKeyNullableRelation[MODEL]": ...
+) -> ForeignKeyNullableRelation[MODEL]: ...
 
 
 @overload
 def ForeignKeyField(
     model_name: str,
-    related_name: Union[Optional[str], Literal[False]] = None,
+    related_name: str | None | Literal[False] = None,
     on_delete: OnDelete = CASCADE,
     db_constraint: bool = True,
     null: Literal[False] = False,
     **kwargs: Any,
-) -> "ForeignKeyRelation[MODEL]": ...
+) -> ForeignKeyRelation[MODEL]: ...
 
 
 def ForeignKeyField(
     model_name: str,
-    related_name: Union[Optional[str], Literal[False]] = None,
+    related_name: str | None | Literal[False] = None,
     on_delete: OnDelete = CASCADE,
     db_constraint: bool = True,
     null: bool = False,
     **kwargs: Any,
-) -> "ForeignKeyRelation[MODEL] | ForeignKeyNullableRelation[MODEL]":
+) -> ForeignKeyRelation[MODEL] | ForeignKeyNullableRelation[MODEL]:
     """
     ForeignKey relation field.
 
@@ -536,15 +537,15 @@ def ForeignKeyField(
 
 def ManyToManyField(
     model_name: str,
-    through: Optional[str] = None,
-    forward_key: Optional[str] = None,
+    through: str | None = None,
+    forward_key: str | None = None,
     backward_key: str = "",
     related_name: str = "",
     on_delete: OnDelete = CASCADE,
     db_constraint: bool = True,
-    create_unique_index: bool = True,
+    unique: bool = True,
     **kwargs: Any,
-) -> "ManyToManyRelation[Any]":
+) -> ManyToManyRelation[Any]:
     """
     ManyToMany relation field.
 
@@ -588,11 +589,10 @@ def ManyToManyField(
                 Can only be set is field has a ``default`` set.
             ``field.NO_ACTION``:
                 Take no action.
-    ``create_unique_index``:
+    ``unique``:
         Controls whether or not a unique index should be created in the database to speed up select queries.
         The default is True. If you want to allow repeat records, set this to False.
     """
-
     return ManyToManyFieldInstance(  # type: ignore
         model_name,
         through,
@@ -601,7 +601,7 @@ def ManyToManyField(
         related_name,
         on_delete=on_delete,
         db_constraint=db_constraint,
-        create_unique_index=create_unique_index,
+        unique=unique,
         **kwargs,
     )
 
